@@ -1,16 +1,16 @@
-package ExtUtils::Manifest;
+package ExtUtils::Manifest; # git description: 1.73-6-gddfed15
 
 require Exporter;
 use Config;
 use File::Basename;
 use File::Copy 'copy';
 use File::Find;
-use File::Spec;
+use File::Spec 0.8;
 use Carp;
 use strict;
 use warnings;
 
-our $VERSION = '1.68';
+our $VERSION = '1.74';
 our @ISA = ('Exporter');
 our @EXPORT_OK = qw(mkmanifest
                 manicheck  filecheck  fullcheck  skipcheck
@@ -56,12 +56,16 @@ our $Verbose = defined $ENV{PERL_MM_MANIFEST_VERBOSE} ?
 our $Quiet = 0;
 our $MANIFEST = 'MANIFEST';
 
-our $DEFAULT_MSKIP = File::Spec->catfile( dirname(__FILE__), "$MANIFEST.SKIP" );
+our $DEFAULT_MSKIP = File::Spec->rel2abs(File::Spec->catfile( dirname(__FILE__), "$MANIFEST.SKIP" ));
 
 
 =head1 NAME
 
-ExtUtils::Manifest - utilities to write and check a MANIFEST file
+ExtUtils::Manifest - Utilities to write and check a MANIFEST file
+
+=head1 VERSION
+
+version 1.74
 
 =head1 SYNOPSIS
 
@@ -85,14 +89,14 @@ ExtUtils::Manifest - utilities to write and check a MANIFEST file
 
 =head1 DESCRIPTION
 
-=head2 Functions
+...
+
+=head1 FUNCTIONS
 
 ExtUtils::Manifest exports no functions by default.  The following are
-exported on request
+exported on request:
 
-=over 4
-
-=item mkmanifest
+=head2 mkmanifest
 
     mkmanifest();
 
@@ -130,25 +134,25 @@ sub mkmanifest {
                      'This list of files'
         if $manimiss; # add new MANIFEST to known file list
     foreach $file (_sort keys %all) {
-	if ($skip->($file)) {
-	    # Policy: only remove files if they're listed in MANIFEST.SKIP.
-	    # Don't remove files just because they don't exist.
-	    warn "Removed from $MANIFEST: $file\n" if $Verbose and exists $read->{$file};
-	    next;
-	}
-	if ($Verbose){
-	    warn "Added to $MANIFEST: $file\n" unless exists $read->{$file};
-	}
-	my $text = $all{$file};
-	$file = _unmacify($file);
-	my $tabs = (5 - (length($file)+1)/8);
-	$tabs = 1 if $tabs < 1;
-	$tabs = 0 unless $text;
+        if ($skip->($file)) {
+            # Policy: only remove files if they're listed in MANIFEST.SKIP.
+            # Don't remove files just because they don't exist.
+            warn "Removed from $MANIFEST: $file\n" if $Verbose and exists $read->{$file};
+            next;
+        }
+        if ($Verbose){
+            warn "Added to $MANIFEST: $file\n" unless exists $read->{$file};
+        }
+        my $text = $all{$file};
+        $file = _unmacify($file);
+        my $tabs = (5 - (length($file)+1)/8);
+        $tabs = 1 if $tabs < 1;
+        $tabs = 0 unless $text;
         if ($file =~ /\s/) {
             $file =~ s/([\\'])/\\$1/g;
             $file = "'$file'";
         }
-	print M $file, "\t" x $tabs, $text, "\n";
+        print M $file, "\t" x $tabs, $text, "\n";
     }
     close M;
 }
@@ -171,7 +175,7 @@ sub clean_up_filename {
 }
 
 
-=item manifind
+=head2 manifind
 
     my $found = manifind();
 
@@ -185,10 +189,10 @@ sub manifind {
     my $found = {};
 
     my $wanted = sub {
-	my $name = clean_up_filename($File::Find::name);
-	warn "Debug: diskfile $name\n" if $Debug;
-	return if -d $_;
-	$found->{$name} = "";
+        my $name = clean_up_filename($File::Find::name);
+        warn "Debug: diskfile $name\n" if $Debug;
+        return if -d $_;
+        $found->{$name} = "";
     };
 
     # We have to use "$File::Find::dir/$_" in preprocess, because
@@ -196,13 +200,13 @@ sub manifind {
     # Also, it's okay to use / here, because MANIFEST files use Unix-style
     # paths.
     find({wanted => $wanted, follow_fast => 1},
-	 $Is_MacOS ? ":" : ".");
+        $Is_MacOS ? ":" : ".");
 
     return $found;
 }
 
 
-=item manicheck
+=head2 manicheck
 
     my @missing_files = manicheck();
 
@@ -220,7 +224,7 @@ sub manicheck {
 }
 
 
-=item filecheck
+=head2 filecheck
 
     my @extra_files = filecheck();
 
@@ -238,7 +242,7 @@ sub filecheck {
 }
 
 
-=item fullcheck
+=head2 fullcheck
 
     my($missing, $extra) = fullcheck();
 
@@ -252,7 +256,7 @@ sub fullcheck {
 }
 
 
-=item skipcheck
+=head2 skipcheck
 
     my @skipped = skipcheck();
 
@@ -324,7 +328,7 @@ sub _check_manifest {
 }
 
 
-=item maniread
+=head2 maniread
 
     my $manifest = maniread();
     my $manifest = maniread($manifest_file);
@@ -391,7 +395,7 @@ sub maniread {
     $read;
 }
 
-=item maniskip
+=head2 maniskip
 
     my $skipchk = maniskip();
     my $skipchk = maniskip($manifest_skip_file);
@@ -412,17 +416,17 @@ sub maniskip {
     local(*M, $_);
     open M, "< $mfile" or open M, "< $DEFAULT_MSKIP" or return sub {0};
     while (<M>){
-      chomp;
-      s/\r//;
-      $_ =~ qr{^\s*(?:(?:'([^\\']*(?:\\.[^\\']*)*)')|([^#\s]\S*))?(?:(?:\s*)|(?:\s+(.*?)\s*))$};
-      #my $comment = $3;
-      my $filename = $2;
-      if ( defined($1) ) {
-        $filename = $1;
-        $filename =~ s/\\(['\\])/$1/g;
-      }
-      next if (not defined($filename) or not $filename);
-      push @skip, _macify($filename);
+        chomp;
+        s/\r//;
+        $_ =~ qr{^\s*(?:(?:'([^\\']*(?:\\.[^\\']*)*)')|([^#\s]\S*))?(?:(?:\s*)|(?:\s+(.*?)\s*))$};
+        #my $comment = $3;
+        my $filename = $2;
+        if ( defined($1) ) {
+          $filename = $1;
+          $filename =~ s/\\(['\\])/$1/g;
+        }
+        next if (not defined($filename) or not $filename);
+        push @skip, _macify($filename);
     }
     close M;
     return sub {0} unless (scalar @skip > 0);
@@ -453,20 +457,20 @@ sub _check_mskip_directives {
     }
     while (<M>) {
         if (/^#!include_default\s*$/) {
-	    if (my @default = _include_mskip_file()) {
-	        push @lines, @default;
-		warn "Debug: Including default MANIFEST.SKIP\n" if $Debug;
-		$flag++;
-	    }
-	    next;
+            if (my @default = _include_mskip_file()) {
+                push @lines, @default;
+                warn "Debug: Including default MANIFEST.SKIP\n" if $Debug;
+                $flag++;
+            }
+            next;
         }
-	if (/^#!include\s+(.*)\s*$/) {
-	    my $external_file = $1;
-	    if (my @external = _include_mskip_file($external_file)) {
-	        push @lines, @external;
-		warn "Debug: Including external $external_file\n" if $Debug;
-		$flag++;
-	    }
+        if (/^#!include\s+(.*)\s*$/) {
+            my $external_file = $1;
+            if (my @external = _include_mskip_file($external_file)) {
+                push @lines, @external;
+                warn "Debug: Including external $external_file\n" if $Debug;
+                $flag++;
+            }
             next;
         }
         push @lines, $_;
@@ -508,7 +512,7 @@ sub _include_mskip_file {
     return @lines;
 }
 
-=item manicopy
+=head2 manicopy
 
     manicopy(\%src, $dest_dir);
     manicopy(\%src, $dest_dir, $how);
@@ -539,22 +543,22 @@ sub manicopy {
     $target = VMS::Filespec::unixify($target) if $Is_VMS_mode;
     File::Path::mkpath([ $target ],! $Quiet,$Is_VMS ? undef : 0755);
     foreach my $file (keys %$read){
-	if ($Is_MacOS) {
-	    if ($file =~ m!:!) {
-		my $dir = _maccat($target, $file);
-		$dir =~ s/[^:]+$//;
-		File::Path::mkpath($dir,1,0755);
-	    }
-	    cp_if_diff($file, _maccat($target, $file), $how);
-	} else {
-	    $file = VMS::Filespec::unixify($file) if $Is_VMS_mode;
-	    if ($file =~ m!/!) { # Ilya, that hurts, I fear, or maybe not?
-		my $dir = File::Basename::dirname($file);
-		$dir = VMS::Filespec::unixify($dir) if $Is_VMS_mode;
-		File::Path::mkpath(["$target/$dir"],! $Quiet,$Is_VMS ? undef : 0755);
-	    }
-	    cp_if_diff($file, "$target/$file", $how);
-	}
+        if ($Is_MacOS) {
+            if ($file =~ m!:!) {
+                my $dir = _maccat($target, $file);
+                $dir =~ s/[^:]+$//;
+                File::Path::mkpath($dir,1,0755);
+            }
+            cp_if_diff($file, _maccat($target, $file), $how);
+        } else {
+            $file = VMS::Filespec::unixify($file) if $Is_VMS_mode;
+            if ($file =~ m!/!) { # Ilya, that hurts, I fear, or maybe not?
+                my $dir = File::Basename::dirname($file);
+                $dir = VMS::Filespec::unixify($dir) if $Is_VMS_mode;
+                File::Path::mkpath(["$target/$dir"],! $Quiet,$Is_VMS ? undef : 0755);
+            }
+            cp_if_diff($file, "$target/$file", $how);
+        }
     }
 }
 
@@ -569,24 +573,24 @@ sub cp_if_diff {
     open(F,"< $from\0") or die "Can't read $from: $!\n";
     if (open(T,"< $to\0")) {
         local $_;
-	while (<F>) { $diff++,last if $_ ne <T>; }
-	$diff++ unless eof(T);
-	close T;
+        while (<F>) { $diff++,last if $_ ne <T>; }
+        $diff++ unless eof(T);
+        close T;
     }
     else { $diff++; }
     close F;
     if ($diff) {
-	if (-e $to) {
-	    unlink($to) or confess "unlink $to: $!";
-	}
+        if (-e $to) {
+            unlink($to) or confess "unlink $to: $!";
+        }
         STRICT_SWITCH: {
-	    best($from,$to), last STRICT_SWITCH if $how eq 'best';
-	    cp($from,$to), last STRICT_SWITCH if $how eq 'cp';
-	    ln($from,$to), last STRICT_SWITCH if $how eq 'ln';
-	    croak("ExtUtils::Manifest::cp_if_diff " .
-		  "called with illegal how argument [$how]. " .
-		  "Legal values are 'best', 'cp', and 'ln'.");
-	}
+            best($from,$to), last STRICT_SWITCH if $how eq 'best';
+            cp($from,$to), last STRICT_SWITCH if $how eq 'cp';
+            ln($from,$to), last STRICT_SWITCH if $how eq 'ln';
+            croak("ExtUtils::Manifest::cp_if_diff " .
+              "called with illegal how argument [$how]. " .
+              "Legal values are 'best', 'cp', and 'ln'.");
+        }
     }
 }
 
@@ -630,9 +634,9 @@ sub best {
 
     my $is_exception = grep $srcFile =~ /$_/, @Exceptions;
     if ($is_exception or !$Config{d_link} or -l $srcFile) {
-	cp($srcFile, $dstFile);
+        cp($srcFile, $dstFile);
     } else {
-	ln($srcFile, $dstFile) or cp($srcFile, $dstFile);
+        ln($srcFile, $dstFile) or cp($srcFile, $dstFile);
     }
 }
 
@@ -643,8 +647,8 @@ sub _macify {
 
     $file =~ s|^\./||;
     if ($file =~ m|/|) {
-	$file =~ s|/+|:|g;
-	$file = ":$file";
+        $file =~ s|/+|:|g;
+        $file = ":$file";
     }
 
     $file;
@@ -673,7 +677,7 @@ sub _unmacify {
 }
 
 
-=item maniadd
+=head2 maniadd
 
   maniadd({ $file => $comment, ...});
 
@@ -690,7 +694,7 @@ sub maniadd {
     _fix_manifest($MANIFEST);
 
     my $manifest = maniread();
-    my @needed = grep { !exists $manifest->{$_} } keys %$additions;
+    my @needed = grep !exists $manifest->{$_}, keys %$additions;
     return 1 unless @needed;
 
     open(MANIFEST, ">>$MANIFEST") or
@@ -737,7 +741,7 @@ sub _fix_manifest {
     if ( $must_rewrite ) {
         1 while unlink $MANIFEST; # avoid multiple versions on VMS
         open MANIFEST, ">", $MANIFEST or die "(must_rewrite=$must_rewrite) Could not open >$MANIFEST: $!";
-	binmode MANIFEST, ':raw';
+        binmode MANIFEST, ':raw';
         for (my $i=0; $i<=$#manifest; $i+=2) {
             print MANIFEST "$manifest[$i]\n";
         }
@@ -751,9 +755,6 @@ sub _normalize {
     return;
 }
 
-
-=back
-
 =head2 MANIFEST
 
 A list of files in the distribution, one file per line.  The MANIFEST
@@ -893,9 +894,14 @@ L<ExtUtils::MakeMaker> which has handy targets for most of the functionality.
 
 Andreas Koenig C<andreas.koenig@anima.de>
 
-Maintained by Michael G Schwern C<schwern@pobox.com> within the
-ExtUtils-MakeMaker package and, as a separate CPAN package, by
-Randy Kobes C<r.kobes@uwinnipeg.ca>.
+Currently maintained by the Perl Toolchain Gang.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 1996- by Andreas Koenig.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
